State

Struct State 

pub struct State {
Show 14 fields pub repo: Rc<Repository>, pub config: Rc<Config>, pub bindings: Bindings, pub pending_keys: Vec<(KeyModifiers, KeyCode)>, pub quit: bool, pub screens: Vec<Screen>, pub pending_menu: Option<PendingMenu>, pub pending_cmd: Option<(Child, Arc<RwLock<CmdLogEntry>>)>, pub enable_async_cmds: bool, pub current_cmd_log: CmdLog, pub prompt: Prompt, pub clipboard: Option<Clipboard>, pub needs_redraw: bool, pub file_watcher: Option<FileWatcher>,
}
The main application state, holding all the necessary data for the UI and Git operations.

Fields

repo: Rc<Repository>

The Git repository being managed.

config: Rc<Config>

Application configuration settings.

bindings: Bindings

Key bindings for various actions.

pending_keys: Vec<(KeyModifiers, KeyCode)>

Keys that have been pressed but not yet matched to a binding.

quit: bool

Flag to indicate if the application should quit.

screens: Vec<Screen>

A stack of currently active screens in the UI.

pending_menu: Option<PendingMenu>

The currently pending menu, if any.

pending_cmd: Option<(Child, Arc<RwLock<CmdLogEntry>>)>

A command that is currently running asynchronously.

enable_async_cmds: bool

Flag to enable or disable asynchronous command execution.

current_cmd_log: CmdLog

Log of commands executed.

prompt: Prompt

The prompt used for user input.

clipboard: Option<Clipboard>

The system clipboard, if available.

needs_redraw: bool

Flag to indicate if the UI needs to be redrawn.

file_watcher: Option<FileWatcher>

Watches for file system changes to trigger UI updates.

Implementations

Source

impl State

pub fn create( repo: Rc<Repository>, size: Size, args: &Args, config: Rc<Config>, enable_async_cmds: bool, ) -> Res<Self>

pub fn run(&mut self, term: &mut Term, max_tick_delay: Duration) -> Res<()>

pub fn update(&mut self, term: &mut Term) -> Res<()>

pub fn handle_event(&mut self, term: &mut Term, event: Event) -> Res<()>

pub fn redraw_now(&mut self, term: &mut Term) -> Res<()>

pub fn stage_redraw(&mut self)

pub fn close_menu(&mut self)

pub fn screen_mut(&mut self) -> &mut Screen

pub fn screen(&self) -> &Screen

pub fn display_info<S: Into<Cow<'static, str>>>(&mut self, message: S)

Displays an Info message to the CmdLog.

pub fn display_error<S: Into<Cow<'static, str>>>(&mut self, message: S)

Displays an Error message to the CmdLog.

pub fn run_cmd( &mut self, term: &mut Term, input: &[u8], cmd: Command, ) -> Res<()>

Runs a Command and handles its output. Will block awaiting its completion.

pub fn run_cmd_async( &mut self, term: &mut Term, input: &[u8], cmd: Command, ) -> Res<()>

Runs a Command and handles its output asynchronously (if async commands are enabled). Will return Ok(()) if one is already running.

pub fn run_cmd_interactive(&mut self, term: &mut Term, cmd: Command) -> Res<()>

pub fn hide_menu(&mut self)

pub fn unhide_menu(&mut self)

pub fn selected_rev(&self) -> Option<String>

pub fn prompt(&mut self, term: &mut Term, params: &PromptParams) -> Res<String>

pub fn confirm(&mut self, term: &mut Term, prompt: &'static str) -> Res<()>